pub struct Actor<T: 'static + Send>(_);
Actor wrapping a state.

Cloning the actor provides an handle to the same actor.

Implementations

Creates a new Actor with default inbound channel capacity (1024).

Returned future must be spawned in an async executor.

Creates a new Actor with given capacity for its inbound channel.

Returned future must be spawned in an async executor.

Queue an async function on the state. The future that this function returns can hold the state across await points, meaning it will prevent other functions to be processed until the future is complete.

queue_blocking resolves once the order is sent to the actor, and doesn’t wait for it to be processed by the actor, but cannot have an output value.

To wait for the order to be processed and get an output, use query_blocking.

Queue a function on the state. It is more performant to have multiple queue/query in a row, as it can avoid using .await on the internal channel or on a future-based change (queue_blocking/query_blocking).

queue resolves once the order is sent to the actor, and doesn’t wait for it to be processed by the actor, but cannot have an output value.

To wait for the order to be processed and get an output, use query.

Queue an async function on the state. The future that this function returns can hold the state across await points, meaning it will prevent other functions to be processed until the future is complete.

query_blocking resolves once the order as been processed by the actor, which allows it to return an output.

If an output is not needed and it is not needed to wait for the order to be processed, use queue_blocking.

Queue a function on the state. It is more performant to have multiple queue/query in a row, as it can avoid using .await on the internal channel or on a future-based change (queue_blocking/query_blocking).

query_blocking resolves once the order as been processed by the actor, which allows it to return an output.

If an output is not needed and it is not needed to wait for the order to be processed, use queue_blocking.

Tells if the actor still accepts new invokes.

Stop the actor, which will process every already queued invokes before really stopping.