pub struct Actor<T: 'static + Send>(_);
Actor wrapping a state.

Cloning the actor provides an handle to the same actor.

Implementations

Creates a new Actor with default inbound channel capacity (1024).

Returned future must be spawned in an async executor.

Creates a new Actor with given capacity for its inbound channel.

Returned future must be spawned in an async executor.

Interacts with the state using a closure returning a future. This future holds the mutable reference to the state, and prevents the actor to process further invokes until this future ends.

The future needs to be boxed using [futures::FutureExt::boxed].

Returns None if the actor is no longer running.

Interact with the state using a closure.

Returns None if the actor is no longer running.

Tells if the actor still accepts new invokes.

Stop the actor, which will process every already queued invokes before really stopping.