pub struct Actor<T: 'static + Send>(_);
Actor wrapping a state.

Implementations

Creates a new Actor with default inbound channel capacity (1024).

Returned future must be spawned in an async executor.

Creates a new Actor with given capacity for its inbound channel.

Returned future must be spawned in an async executor.

Interact with the state. Returns None if the actor is no longer running.

Interact with the state then awaits a Future. This Future cannot hold the reference to the state.

Tells if the actor still accepts new invokes.

Stop the actor, which will process every already queued invokes before really stopping.